/*
 * Paraselene
 * Copyright (c) 2009  Akira Terasaki
 * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
 * 利用可能です。
 */
package paraselene.ajax.data;

import paraselene.*;
import paraselene.supervisor.*;
import java.io.*;

public class Exec implements Serializable {
	private static final long serialVersionUID = 2L;

	public String[]	cmd = null;

	private Exec(){}
	public Exec( String ... c ) {
		cmd = c;
	}
}

